@@ -1,5 +1,4 @@
 import sys
-from typing import TYPE_CHECKING, cast
 
 import click
 import requests
@@ -8,10 +7,7 @@ import validators
 from sym.flow.cli.helpers.config import Config, store_login_config
 from sym.flow.cli.helpers.global_options import GlobalOptions
 from sym.flow.cli.helpers.jwt import JWT
-from sym.flow.cli.helpers.login.login_flow import LoginFlow
-
-if TYPE_CHECKING:
-    from sym.flow.cli.helpers.login.login_flow import BrowserRedirectFlow
+from sym.flow.cli.helpers.login.login_flow import BrowserRedirectFlow
 
 
 def validate_email(ctx, param, value):
@@ -23,21 +19,19 @@ def validate_email(ctx, param, value):
 
 @click.command(short_help="Log in to your Sym account")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
-@click.option(
-    "--browser/--no-browser",
-    default=True,
-    is_flag=True,
-)
 @click.option(
     "--port",
     default=11001,
+    help="Port to use for the local webserver.",
+    show_default=True,
 )
 @click.option(
     "--org-slug",
     prompt=True,
     default=lambda: Config.get_org().slug if Config.is_logged_in() else None,
+    help="The slug of the Organization you want to log in to.",
 )
-def login(options: GlobalOptions, browser: bool, port: int, org_slug: str) -> None:
+def login(options: GlobalOptions, port: int, org_slug: str) -> None:
     """Log in to your Sym account to authenticate with the Sym API. This is required to enable privileged actions within your Organization such as authoring Sym Flows or installing the Slack App.
 
     \b
@@ -49,17 +43,14 @@ def login(options: GlobalOptions, browser: bool, port: int, org_slug: str) -> No
         sys.exit(1)
 
     org = options.sym_api.get_organization_from_slug(org_slug)
-    flow = LoginFlow.get_login_flow(browser, port)
+    flow = BrowserRedirectFlow(port)
 
-    if browser:
-        (url, *_) = cast("BrowserRedirectFlow", flow).gen_browser_login_params(
-            options, org
-        )
-        styled_url = click.style(requests.utils.requote_uri(url), bold=True)  # type: ignore
-        click.echo(
-            f"Opening the login page in your browser. If this doesn't work, please visit the following URL:\n"
-            f"{styled_url}\n"
-        )
+    url, *_ = flow.gen_browser_login_params(options, org)
+    styled_url = click.style(requests.utils.requote_uri(url), bold=True)  # type: ignore
+    click.echo(
+        f"Opening the login page in your browser. If this doesn't work, please visit the following URL:\n"
+        f"{styled_url}\n"
+    )
 
     # It's possible to not get an auth_token AND not have raised an exception before getting here
     # if the user has just signed up.
