@@ -1,6 +1,7 @@
 import click
 
 from sym.flow.cli.helpers.global_options import GlobalOptions
+from sym.flow.cli.models import ServiceType
 from sym.flow.cli.models.service import BaseService
 from sym.flow.cli.models.user import CSVMatcher
 
@@ -9,19 +10,18 @@ from sym.flow.cli.models.user import CSVMatcher
     name="delete",
     short_help="Delete a User",
 )
-@click.argument("service", required=True, type=str)
-@click.option("--user-id", required=True, type=str)
+@click.argument("email", required=True, type=str)
 @click.make_pass_decorator(GlobalOptions, ensure=True)
-def users_delete(options: GlobalOptions, service: str, user_id: str) -> None:
+def users_delete(options: GlobalOptions, email: str) -> None:
     # External ID is not used, using service as a placeholder
-    service_obj = BaseService(slug=service, external_id=service)
-    matcher = CSVMatcher(service=service_obj, value=user_id)
+    service_obj = BaseService(slug=ServiceType.SYM.type_name, external_id="cloud")
+    matcher = CSVMatcher(service=service_obj, value=email)
 
     payload = {
         "users": [
             {
                 "identity": {
-                    "service_type": service,
+                    "service_type": ServiceType.SYM.type_name,
                     "matcher": matcher.to_dict(),
                 },
             }
@@ -29,4 +29,4 @@ def users_delete(options: GlobalOptions, service: str, user_id: str) -> None:
     }
 
     options.sym_api.delete_user(payload)
-    click.secho(f"Successfully deleted user {user_id}!")
+    click.secho(f"Successfully deleted user {email}!")
