@@ -11,12 +11,7 @@ from sym.flow.cli.helpers.utils import human_friendly, utc_to_local
 @click.command(name="list", short_help="List all Users")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 def users_list(options: GlobalOptions) -> None:
-    """Lists all Users in your organization.
-
-    Note: To see a list of all User identities, use:
-
-        `symflow users list-identities`
-    """
+    """Lists all Users in your organization."""
     table_data = get_user_data(options.sym_api)
     click.echo(tabulate(table_data, headers="firstrow"))
 
