@@ -1,15 +1,8 @@
-from dataclasses import dataclass
 from typing import TypedDict
 
 from sym.flow.cli.errors import InvalidTokenError
 
 
-@dataclass
-class UserCredentials:
-    username: str
-    password: str
-
-
 class AuthToken(TypedDict):
     access_token: str
     refresh_token: str
