@@ -1,8 +1,8 @@
-from sym.cli.helpers.config import init as config_init
+from sym.shared.cli.helpers.config import init as config_init
 
 config_init("symflow")
 
-from sym.cli.helpers.init import sym_init
+from sym.shared.cli.helpers.init import sym_init
 
 from .commands import import_all
 from .commands.symflow import symflow
