@@ -54,7 +54,9 @@ def login_tester(click_setup):
         expected_output: List[str],
         success: bool = True,
     ):
-        with patch.object(LoginFlow, "get_login_flow", return_value=login_flow):
+        with patch(
+            "sym.flow.cli.commands.login.BrowserRedirectFlow", return_value=login_flow
+        ):
             with click_setup() as runner:
                 result = runner.invoke(click_command, ["login", "--org-slug", org_slug])
                 print(result.output)
